@@ -4,10 +4,11 @@ test_that("geojson_validate works with character inputs", {
   a <- geojson_validate('{"type": "FooBar"}')
   expect_is(a, "logical")
   expect_equal(a, FALSE)
-  
+
   # listid
-  expect_equal(geojson_validate('{"type": "Point", "coordinates": [-80,40]}'), TRUE)
-  
+  expect_equal(
+    geojson_validate('{"type": "Point", "coordinates": [-80,40]}'), TRUE)
+
   # invalid
   expect_equal(geojson_validate('{ "type": "FeatureCollection" }'), FALSE)
   expect_equal(geojson_validate('{"type":"Point","geometry":{"type":"Point","coordinates":[-80,40]},"properties":{}}'), FALSE)
@@ -23,7 +24,7 @@ test_that("geojson_validate works with file inputs", {
 
 test_that("geojson_validate works with url inputs", {
   skip_on_cran()
-  
+
   url <- "https://raw.githubusercontent.com/glynnbird/usstatesgeojson/master/california.geojson"
   e <- geojson_validate(as.location(url))
   expect_is(as.location(url), "location")
